@@ -7,7 +7,7 @@
 #' fn <- function(x) x ^ 4 - x ^ 2
 #' x <- runif(2000,-3,3)
 #' y <- fn(x) + rnorm(2000,0,0.1)
-#' ct <- covatree(coord = x,obs = y,h = 0.5,p = 3L, minLeft = 50)
+#' ct <- covatree(coord = x,obs = y,p = 5L, minLeft = 50)
 #' ct$getDim()
 #' x0 <- seq(-1,1,0.1)
 #' y0 <- ct$predict(x0)
@@ -26,8 +26,8 @@ covatree <- setRefClass("covatree",
 
                             initialize = function(coord,
                                                   obs,
-                                                  h = 1.0, 
-                                                  p = 2L,
+                                                  h = suggestBandwith(coord,p), 
+                                                  p = 3L,
                                                   minLeft = length(obs)/10,
                                                   ...){
                                 "Method to initialize the covafill. coord is a matrix of coordinates, obs is a vector of corresponding observations, h is a vector of bandwiths, p is the polynomial degree, and minLeft is the minimum number of observations that will create a sub tree."
